Crate from_pg_derive

Crate from_pg_derive 

Derive Macros

FromPg
For a type using the frompg macro, you can write #[frompg(from = T, func = F)] above a field. This retrieves any valid attributes from a field, and can return an error.